@@ -46,17 +46,6 @@ urlpatterns += patterns('',
     (r'^avatar/', include('avatar.urls')),
     (r'^dashboard/', include('tendenci.apps.dashboard.urls')),
     (r'^categories/', include('tendenci.core.categories.urls')),
-    (r'^memberships/', include('tendenci.addons.memberships.urls')),
-    (r'^corporatememberships/', include('tendenci.addons.corporate_memberships.urls')),
-    (r'^entities/', include('tendenci.apps.entities.urls')),
-    (r'^pages/', include('tendenci.apps.pages.urls')),
-    (r'^users/', include('tendenci.apps.profiles.urls')),
-    (r'^photos/', include('tendenci.addons.photos.urls')),
-    (r'^forms/', include('tendenci.apps.forms_builder.forms.urls')),
-    (r'^events/', include('tendenci.addons.events.urls')),
-    (r'^profiles/', include('tendenci.apps.profiles.urls')),
-    (r'^groups/', include('tendenci.apps.user_groups.urls')),
-    (r'^stories/', include('tendenci.apps.stories.urls')),
     (r'^invoices/', include('tendenci.apps.invoices.urls')),
     (r'^py/', include('tendenci.addons.make_payments.urls')),
     (r'^payments/', include('tendenci.core.payments.urls')),
@@ -67,11 +56,9 @@ urlpatterns += patterns('',
     (r'^imports/', include('tendenci.core.imports.urls')),
     #(r'^donations/', include('donations.urls')),
     (r'^settings/', include('tendenci.core.site_settings.urls')),
-    (r'^files/', include('tendenci.core.files.urls')),
     (r'^accounts/', include('tendenci.apps.accounts.urls')),
     (r'^search/', include('tendenci.apps.search.urls')),
     (r'^event-logs/', include('tendenci.core.event_logs.urls')),
-    (r'^contributions/', include('tendenci.apps.contributions.urls')),
     (r'^theme-editor/', include('tendenci.apps.theme_editor.urls')),
     (r'^exports/', include('tendenci.core.exports.urls')),
     (r'^ics/', include('tendenci.addons.events.ics.urls')),
@@ -81,7 +68,6 @@ urlpatterns += patterns('',
 
     (r'^subscribers/', include('tendenci.apps.subscribers.urls')),
     (r'^redirects/', include('tendenci.apps.redirects.urls')),
-    (r'^resumes/', include('tendenci.addons.resumes.urls')),
     (r'^mobile/', include('tendenci.core.mobile.urls')),
     (r'^campaign_monitor/', include('tendenci.addons.campaign_monitor.urls')),
     (r'^wp_importer/', include('tendenci.apps.wp_importer.urls')),
@@ -105,13 +91,26 @@ urlpatterns += patterns('',
     # legacy redirects
     url(r'^login/$', redirect_to, {'url': '/accounts/login/'}),
 
-    url(r'^', include('tendenci.apps.contacts.urls')),
     url(r'^', include('tendenci.addons.articles.urls')),
-    url(r'^', include('tendenci.addons.jobs.urls')),
+    url(r'^', include('tendenci.addons.corporate_memberships.urls')),
     url(r'^', include('tendenci.addons.directories.urls')),
+    url(r'^', include('tendenci.addons.events.urls')),
     url(r'^', include('tendenci.addons.help_files.urls')),
+    url(r'^', include('tendenci.addons.jobs.urls')),
     url(r'^', include('tendenci.addons.locations.urls')),
+    url(r'^', include('tendenci.addons.memberships.urls')),
     url(r'^', include('tendenci.addons.news.urls')),
+    url(r'^', include('tendenci.addons.photos.urls')),
+    url(r'^', include('tendenci.addons.resumes.urls')),
+    url(r'^', include('tendenci.apps.contacts.urls')),
+    url(r'^', include('tendenci.apps.contributions.urls')),
+    url(r'^', include('tendenci.apps.entities.urls')),
+    url(r'^', include('tendenci.apps.forms_builder.forms.urls')),
+    url(r'^', include('tendenci.apps.pages.urls')),
+    url(r'^', include('tendenci.apps.profiles.urls')),
+    url(r'^', include('tendenci.apps.stories.urls')),
+    url(r'^', include('tendenci.apps.user_groups.urls')),
+    url(r'^', include('tendenci.core.files.urls')),
     url(r'^', include('tendenci.core.newsletters.urls')),
 )
 
